==> style-0.0.1.tar.gz: lib/style.dart <==
library style;


import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:style/Color.dart';

class Style{


  TextStyle? loginText,bottomBarSelected,bottomBarUnSelected,appName,appDes,buttonWhite,buttonBlue;
  TextStyle? resendOtp,resendTimer,appBar,appBarTeal,h4Black,h3Blue,h4Grey,dateText,appointmentCount,h4White,dateTextSheet;
  TextStyle? editStyle,editHint,cancel,patientName,patientDes,patientTime,patientDesBlue,patientDesBlack
  ,h4DayWhite,slotsWhite,h4DayBlue,h4Blue,h2Blue,h5DayBlue,h5DayWhite,slotsBlue,h6Grey,h5BlueBold,h3WhiteBold,h5Black;


  Style(context){

    Dimensions dimensions = Dimensions(context: context);
    loginText = TextStyle(color: AppColor.black, fontSize: dimensions.h3,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    bottomBarSelected = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    bottomBarUnSelected = TextStyle(color: AppColor.black, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    appName = TextStyle(color: AppColor.blue, fontSize: dimensions.h2,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    appDes = TextStyle(color: AppColor.appOrange, fontSize: dimensions.h1,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    buttonWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    buttonBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    resendOtp = TextStyle(color: AppColor.grey, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    h5BlueBold = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    resendTimer = TextStyle(color: AppColor.red, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    appBar = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    h3WhiteBold = TextStyle(color: Colors.white, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    appBarTeal = TextStyle(color: AppColor.teal, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeGras);
    h4Black = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h3Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeGras);
    h4Grey = TextStyle(color: AppColor.grey, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    dateText = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 1, fontFamily: Fonts.segoe);
    dateTextSheet = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoe);
    appointmentCount = TextStyle(color: AppColor.white, fontSize: dimensions.h1 * 1.5,letterSpacing: 2, fontFamily: Fonts.segoeSemiLight);
    h4White = TextStyle(color: AppColor.white, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    editStyle = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 1, fontFamily: Fonts.segoe);
    editHint = TextStyle(color: AppColor.grey, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    cancel = TextStyle(color: Colors.red, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientName = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientDes = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    patientDesBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientTime = TextStyle(color: AppColor.teal, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h4DayWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    slotsWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    h4DayBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    h5DayBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    h5DayWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    slotsBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    patientDesBlack = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h6Grey = TextStyle(color: AppColor.grey, fontSize: dimensions.h6,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiLight);
    h2Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h2,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiLight);
    h5Black = TextStyle(color: Colors.black87, fontSize: dimensions.h5,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    h4Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);

  }
}

class Dimensions {

  late MediaQueryData _mediaQueryData;
  double? screenWidth;
  double? screenHeight;
  double? blockSizeHorizontal;
  double? blockSizeVertical;
  double? devicePixelRatio;

  double? _safeAreaHorizontal;
  late double _safeAreaVertical;
  double? safeBlockHorizontal;
  double? safeBlockVertical;

  double? fontH1;
  double? fontH2;
  double? fontH3;
  double? fontH4;
  double? fontH5;
  double? fontH6;
  double? font13;
  double? font20;

  Dimensions({required BuildContext context,double? width,double? height}){

    _mediaQueryData = MediaQuery.of(context);
    if(width == null || height == null){

      screenWidth = _mediaQueryData.size.width;
      screenHeight = _mediaQueryData.size.height;
      devicePixelRatio = _mediaQueryData.devicePixelRatio;
    }else{
      screenWidth = width;
      screenHeight = height;
    }

    screenWidth = kIsWeb ? (screenWidth! - 80) : screenWidth;

    _safeAreaHorizontal = _mediaQueryData.padding.left +
        _mediaQueryData.padding.right;
    _safeAreaVertical = _mediaQueryData.padding.top +
        _mediaQueryData.padding.bottom;
    safeBlockHorizontal = (screenWidth! - _safeAreaHorizontal!) / 100;
    safeBlockVertical = (screenHeight! -
        _safeAreaVertical) / 100;



    fontH1 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 18.7;  // 24
    fontH2 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 20.4;  // 22
    font20 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 22.45; // 20
    fontH3 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 25;    //18
    fontH4 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 28;  // 16
    fontH5 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 32;  //14
    font13 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 34.5;  //13
    fontH6 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 37.4;  //12
  }

  get buttonSize{
    return screenWidth! >= 500 ? screenHeight! / 1.75 : screenWidth;
  }

  get safeAreaHorizontal{
    return _safeAreaHorizontal;
  }

  get width{
    return screenWidth;
  }

  get height{
    return screenHeight;
  }

  get deviceRatio{
    return devicePixelRatio;
  }

  get h1{
    return fontH1;
  }

  get h2{
    return fontH2;
  }

  get h3{
    return fontH3;
  }

  get h4{
    return fontH4;
  }

  get h5{
    return fontH5;
  }

  get h6{
    return fontH6;
  }

  get text_13{
    return font13;
  }

  get padding_3{
    if(screenWidth! >= 500){
      return screenHeight! / 100;
    }else{
      return screenWidth! / 100;
    }
  }

  get padding_7{
    if(screenWidth! >= 500) {
      return screenHeight! / 64;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 64;
    }
  }

  get padding_10{
    if(screenWidth! >= 500) {
      return screenHeight! / 69;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 44.9;
    }
  }

  get padding_15{
    if(screenWidth! >= 500) {
      return screenHeight! / 47;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 30;
    }
  }

  get button{
    if(screenWidth! >= 500) {
      return padding_20 - padding_3 + 1;
    }else{
      return padding_20 - padding_3 + 1;
    }
  }

  get padding_20{
    if(screenWidth! >= 500) {
      return screenHeight! / 35;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 22.45;
    }
  }

  get padding_24{
    if(screenWidth! >= 500) {
      return screenHeight! / 30;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 18.7;
    }
  }

  get padding_25{
    if(screenWidth! >= 500) {
      return screenHeight! / 28.5;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 17.96;
    }
  }

  get padding_30{
    if(screenWidth! >= 500) {
      return screenHeight! / 24;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 14.96;
    }
  }

  get padding_35{
    if(screenWidth! >= 500) {
      return screenHeight! / 20.5;
    }else{
      return screenWidth! / 12.85;
    }
  }

  get padding_40{
    if(screenWidth! >= 500) {
      return screenHeight! / 18;
    }else{
      return screenWidth! / 10.97;
    }
  }

  get padding_45{
    if(screenWidth! >= 500) {
      return screenHeight! / 16;
    }else{
      return screenWidth! / 9.98;
    }
  }

  get padding_50{
    if(screenWidth! >= 500) {
      return screenHeight! / 14.4;
    }else{
      return screenWidth! / 8.99;
    }
  }

  get padding_60{
    if(screenWidth! >= 500) {
      return screenHeight! / 12;
    }else{
      return screenWidth! / 7.49;
    }
  }

  get padding_70{
    if(screenWidth! >= 500) {
      return screenHeight! / 10.2;
    }else{
      return screenWidth! / 6.43;
    }
  }

  get padding_80{
    if(screenWidth! >= 500) {
      return screenHeight! / 9;
    }else{
      return screenWidth! / 5.59;
    }
  }

  get padding_90{
    if(screenWidth! >= 500) {
      return screenHeight! / 8;
    }else{
      return screenWidth! / 4.99;
    }
  }

  get padding_120{
    if(screenWidth! >= 500) {
      return screenHeight! / 6;
    }else{
      return screenWidth! / 3.75;
    }
  }

  get padding_150{
    if(screenWidth! >= 500) {
      return screenHeight! / 4.8;
    }else{
      return screenWidth! / 3;
    }
  }

}

class Fonts{
  // Font
  static String segoe = "Segoe";
  static String segoeBlack = "SegoeBlack";
  static String segoeBlackItalic = "SegoeBlackItalic";
  static String segoeGras = "SegoeGras";
  static String segoeSemiLight = "SegoeSemilight";
  static String segoeSemiBold = "SegoeSemibold";
}

==> style-0.0.2.tar.gz: lib/style.dart <==
library style;


import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:style/Color.dart';

class Style{


  TextStyle? loginText,bottomBarSelected,bottomBarUnSelected,appName,appDes,buttonWhite,buttonBlue;
  TextStyle? resendOtp,resendTimer,appBar,appBarTeal,h4Black,h3Blue,h4Grey,dateText,appointmentCount,h4White,dateTextSheet;
  TextStyle? editStyle,editHint,cancel,patientName,patientDes,patientTime,patientDesBlue,patientDesBlack
  ,h4DayWhite,slotsWhite,h4DayBlue,h4Blue,h2Blue,h5DayBlue,h5DayWhite,slotsBlue,h6Grey,h5BlueBold,h3WhiteBold,h5Black,h6Blue;


  Style(context){

    Dimensions dimensions = Dimensions(context: context);
    loginText = TextStyle(color: AppColor.black, fontSize: dimensions.h3,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    bottomBarSelected = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    bottomBarUnSelected = TextStyle(color: AppColor.black, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeGras);
    appName = TextStyle(color: AppColor.blue, fontSize: dimensions.h2,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    appDes = TextStyle(color: AppColor.appOrange, fontSize: dimensions.h1,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    buttonWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    buttonBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    resendOtp = TextStyle(color: AppColor.grey, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    h5BlueBold = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiBold);
    resendTimer = TextStyle(color: AppColor.red, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    appBar = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    h3WhiteBold = TextStyle(color: Colors.white, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    appBarTeal = TextStyle(color: AppColor.teal, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoeGras);
    h4Black = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h3Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeGras);
    h4Grey = TextStyle(color: AppColor.grey, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    dateText = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 1, fontFamily: Fonts.segoe);
    dateTextSheet = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 1, fontFamily: Fonts.segoe);
    appointmentCount = TextStyle(color: AppColor.white, fontSize: dimensions.h1 * 1.5,letterSpacing: 2, fontFamily: Fonts.segoeSemiLight);
    h4White = TextStyle(color: AppColor.white, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    editStyle = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 1, fontFamily: Fonts.segoe);
    editHint = TextStyle(color: AppColor.grey, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    cancel = TextStyle(color: Colors.red, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientName = TextStyle(color: AppColor.blue, fontSize: dimensions.h3,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientDes = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    patientDesBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    patientTime = TextStyle(color: AppColor.teal, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h4DayWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    slotsWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    h4DayBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    h5DayBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    h5DayWhite = TextStyle(color: AppColor.white, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoe);
    slotsBlue = TextStyle(color: AppColor.blue, fontSize: dimensions.h5,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiLight);
    patientDesBlack = TextStyle(color: AppColor.black, fontSize: dimensions.h4,letterSpacing: 0.8, fontFamily: Fonts.segoeSemiBold);
    h6Grey = TextStyle(color: AppColor.grey, fontSize: dimensions.h6,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiLight);
    h2Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h2,letterSpacing: 0.5, fontFamily: Fonts.segoeSemiLight);
    h5Black = TextStyle(color: Colors.black87, fontSize: dimensions.h5,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    h4Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);
    h6Blue = TextStyle(color: AppColor.blue, fontSize: dimensions.h4,letterSpacing: 1, fontFamily: Fonts.segoeSemiBold);

  }
}

class Dimensions {

  late MediaQueryData _mediaQueryData;
  double? screenWidth;
  double? screenHeight;
  double? blockSizeHorizontal;
  double? blockSizeVertical;
  double? devicePixelRatio;

  double? _safeAreaHorizontal;
  late double _safeAreaVertical;
  double? safeBlockHorizontal;
  double? safeBlockVertical;

  double? fontH1;
  double? fontH2;
  double? fontH3;
  double? fontH4;
  double? fontH5;
  double? fontH6;
  double? font13;
  double? font20;

  Dimensions({required BuildContext context,double? width,double? height}){

    _mediaQueryData = MediaQuery.of(context);
    if(width == null || height == null){

      screenWidth = _mediaQueryData.size.width;
      screenHeight = _mediaQueryData.size.height;
      devicePixelRatio = _mediaQueryData.devicePixelRatio;
    }else{
      screenWidth = width;
      screenHeight = height;
    }

    screenWidth = kIsWeb ? (screenWidth! - 80) : screenWidth;

    _safeAreaHorizontal = _mediaQueryData.padding.left +
        _mediaQueryData.padding.right;
    _safeAreaVertical = _mediaQueryData.padding.top +
        _mediaQueryData.padding.bottom;
    safeBlockHorizontal = (screenWidth! - _safeAreaHorizontal!) / 100;
    safeBlockVertical = (screenHeight! -
        _safeAreaVertical) / 100;



    fontH1 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 18.7;  // 24
    fontH2 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 20.4;  // 22
    font20 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 22.45; // 20
    fontH3 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 25;    //18
    fontH4 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 28;  // 16
    fontH5 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 32;  //14
    font13 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 34.5;  //13
    fontH6 = (screenWidth! >= 500 ? screenHeight! / 2 : screenWidth)! / 37.4;  //12
  }

  get buttonSize{
    return screenWidth! >= 500 ? screenHeight! / 1.75 : screenWidth;
  }

  get safeAreaHorizontal{
    return _safeAreaHorizontal;
  }

  get width{
    return screenWidth;
  }

  get height{
    return screenHeight;
  }

  get deviceRatio{
    return devicePixelRatio;
  }

  get h1{
    return fontH1;
  }

  get h2{
    return fontH2;
  }

  get h3{
    return fontH3;
  }

  get h4{
    return fontH4;
  }

  get h5{
    return fontH5;
  }

  get h6{
    return fontH6;
  }

  get text_13{
    return font13;
  }

  get padding_3{
    if(screenWidth! >= 500){
      return screenHeight! / 100;
    }else{
      return screenWidth! / 100;
    }
  }

  get padding_7{
    if(screenWidth! >= 500) {
      return screenHeight! / 64;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 64;
    }
  }

  get padding_10{
    if(screenWidth! >= 500) {
      return screenHeight! / 69;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 44.9;
    }
  }

  get padding_15{
    if(screenWidth! >= 500) {
      return screenHeight! / 47;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 30;
    }
  }

  get button{
    if(screenWidth! >= 500) {
      return padding_20 - padding_3 + 1;
    }else{
      return padding_20 - padding_3 + 1;
    }
  }

  get padding_20{
    if(screenWidth! >= 500) {
      return screenHeight! / 35;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 22.45;
    }
  }

  get padding_24{
    if(screenWidth! >= 500) {
      return screenHeight! / 30;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 18.7;
    }
  }

  get padding_25{
    if(screenWidth! >= 500) {
      return screenHeight! / 28.5;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 17.96;
    }
  }

  get padding_30{
    if(screenWidth! >= 500) {
      return screenHeight! / 24;
    }else{
      return (screenWidth! - _safeAreaHorizontal!) / 14.96;
    }
  }

  get padding_35{
    if(screenWidth! >= 500) {
      return screenHeight! / 20.5;
    }else{
      return screenWidth! / 12.85;
    }
  }

  get padding_40{
    if(screenWidth! >= 500) {
      return screenHeight! / 18;
    }else{
      return screenWidth! / 10.97;
    }
  }

  get padding_45{
    if(screenWidth! >= 500) {
      return screenHeight! / 16;
    }else{
      return screenWidth! / 9.98;
    }
  }

  get padding_50{
    if(screenWidth! >= 500) {
      return screenHeight! / 14.4;
    }else{
      return screenWidth! / 8.99;
    }
  }

  get padding_60{
    if(screenWidth! >= 500) {
      return screenHeight! / 12;
    }else{
      return screenWidth! / 7.49;
    }
  }

  get padding_70{
    if(screenWidth! >= 500) {
      return screenHeight! / 10.2;
    }else{
      return screenWidth! / 6.43;
    }
  }

  get padding_80{
    if(screenWidth! >= 500) {
      return screenHeight! / 9;
    }else{
      return screenWidth! / 5.59;
    }
  }

  get padding_90{
    if(screenWidth! >= 500) {
      return screenHeight! / 8;
    }else{
      return screenWidth! / 4.99;
    }
  }

  get padding_120{
    if(screenWidth! >= 500) {
      return screenHeight! / 6;
    }else{
      return screenWidth! / 3.75;
    }
  }

  get padding_150{
    if(screenWidth! >= 500) {
      return screenHeight! / 4.8;
    }else{
      return screenWidth! / 3;
    }
  }

}

class Fonts{
  // Font
  static String segoe = "Segoe";
  static String segoeBlack = "SegoeBlack";
  static String segoeBlackItalic = "SegoeBlackItalic";
  static String segoeGras = "SegoeGras";
  static String segoeSemiLight = "SegoeSemilight";
  static String segoeSemiBold = "SegoeSemibold";
}
